@@ -8,5 +8,5 @@ class ConfigurationError(Exception):
     pass
 
 class RateLimitExceeded(Exception):
-    def __init__(self, msg=None):
-        abort(429, msg)
+    def __init__(self, limit):
+        abort(429, str(limit))
